import { world } from '@minecraft/server';
import CONFIG from '../config.js';

class Logger {
    static debug(message, feature = '') {
        if (CONFIG.DEBUG) {
            // Make sure we have a valid color
            const color = this.getColorCode(feature);
            const prefix = feature ? `${color}[${feature}]` : `${color}[DEBUG]`;
            world.sendMessage(`${prefix} ${message}`);
        }
    }

    static info(message, feature = '') {
        if (CONFIG.DEBUG) {
            // Make sure we have a valid color
            const color = this.getColorCode(feature);
            const prefix = feature ? `${color}[${feature}]` : `${color}[INFO]`;
            world.sendMessage(`${prefix} ${message}`);
        }
    }

    static warn(message, feature = '') {
        if (CONFIG.DEBUG) {
            const prefix = feature ? `§e[${feature}]` : `§e[WARN]`;
            world.sendMessage(`${prefix} ${message}`);
        }
    }

    static error(message, feature = '') {
        if (CONFIG.DEBUG) {
            const prefix = feature ? `§c[${feature}]` : `§c[ERROR]`;
            world.sendMessage(`${prefix} ${message}`);
        }
    }

    // Helper method to get a valid color code
    static getColorCode(feature) {
        // Make sure CONFIG.LOGGING.COLORS exists
        if (!CONFIG.LOGGING || !CONFIG.LOGGING.COLORS) {
            return '§f'; // Default to white if config is missing
        }
        
        // Get the color for the feature, or use SYSTEM color, or default to white
        return (CONFIG.LOGGING.COLORS[feature] || 
                CONFIG.LOGGING.COLORS.SYSTEM || 
                '§f');
    }
}

export default Logger;